@@ -9,9 +9,9 @@ class SharePointList:
     '''
     '''
 
-    settings = None
-    _items = None
-    sharepoint_site = None
+    settings = {}
+    _items = {}
+    sharepoint_site = ""
     SPItem = SharePointListItem
 
     CHANGE_DETECTED = False
@@ -25,7 +25,7 @@ class SharePointList:
 
     def __str__(self):
         items = ''
-        for _, _item in self.all_items.items():
+        for item_id, _item in self.all_items.items():
             items = items+str(_item.Title)+'\n'
         return items
 
@@ -36,7 +36,7 @@ class SharePointList:
             self.save_as_json(self.JSON_FILENAME)
 
     @property
-    def all_items(self):
+    def all_items(self) -> dict[int, SPItem]:
         '''
             Get list of all SharePointListItem objects
         '''
@@ -51,7 +51,7 @@ class SharePointList:
         '''
         if self._items is None:
             self._items = {}
-        return list(self._items.values())
+        return self._items.values()
 
     @property
     def Title(self) -> str:
@@ -62,8 +62,6 @@ class SharePointList:
         return self.settings['Id']
 
     def append_items(self, items):
-        if self._items is None:
-            self._items = {}
 
         if isinstance(items, list):
             for item in items:
